@@ -6,6 +6,8 @@
 #' @param inputId The input slot that will be used to access the value.
 #' @param keys A character vector of keys to bind. Examples include, `command`,
 #' `command+shift+a`, `up down left right`, and more.
+#' @param global Should keys work anywhere? If TRUE, keys are triggered when
+#' inside a textInput.
 #'
 #' @examples
 #' \dontrun{
@@ -29,8 +31,8 @@
 #' }
 #'
 #' @export
-keysInput <- function(inputId, keys) {
+keysInput <- function(inputId, keys, global = FALSE) {
   htmltools::tagList(
-    keys_js(inputId, keys)
+    keys_js(inputId, keys, global)
   )
 }
