@@ -4,13 +4,15 @@ minify <- function(x) {
 
 #' @importFrom htmltools tags
 #' @importFrom jsonlite toJSON
-keys_js <- function(id, keys) {
+keys_js <- function(id, keys, global = FALSE) {
+  if (global) global <- "Global"
+  else global <- ""
 
   x <- sprintf("$(document).on('shiny:sessioninitialized', function() {
-    Mousetrap.bind(%s, function(e, combo) {
+    Mousetrap.bind%s(%s, function(e, combo) {
       Shiny.setInputValue('%s', combo, {priority: 'event'});
     });
-  });", toJSON(keys), id)
+  });", global, toJSON(keys), id)
 
   tags$head(
     tags$script(
